﻿
Imports System.Drawing
Imports Rhino
Imports Rhino.Display
Imports Rhino.Geometry

Public Class LWS_CustomConduitDemoBug
    Inherits Rhino.Display.DisplayConduit

    Private Sub DrawAnnotations(e As DrawEventArgs)

        'Simplified version
        Dim td As New TextDot("This is a test", New Point3d(10, 20, 0))
        td.FontHeight = 10
        e.Display.DisplayPipelineAttributes.DisableTransparency = True
        e.Display.DrawDot(td, Color.Pink, Color.Black, Color.Red)

    End Sub

    Private Sub DrawGlobalGravityCenter(e As DrawEventArgs)
        If e.RhinoDoc IsNot Nothing Then

            'Global Gravity center
            Dim GlobalGPoint As Point3d = New Point3d(30, 30, 20)
            Dim Length As Double = 1000000
            Dim MyColor As Color = Color.DarkBlue
            MyColor = Color.FromArgb(120, MyColor) 'Transparency from 0 to 255

            'Scale text and line size
            Dim pixelsperunits As Double = 1
            e.RhinoDoc.Views.ActiveView.ActiveViewport.GetWorldToScreenScale(GlobalGPoint, pixelsperunits)
            Dim FontHeight As Integer = 10
            Dim DisplayHeight As Double = (FontHeight / pixelsperunits) * 3 / 4

            'Get the points
            Dim start1 As New Point3d(GlobalGPoint.X - Length, GlobalGPoint.Y, GlobalGPoint.Z)
            Dim end1 As New Point3d(GlobalGPoint.X + Length, GlobalGPoint.Y, GlobalGPoint.Z)
            Dim start2 As New Point3d(GlobalGPoint.X, GlobalGPoint.Y - Length, GlobalGPoint.Z)
            Dim end2 As New Point3d(GlobalGPoint.X, GlobalGPoint.Y + Length, GlobalGPoint.Z)
            Dim start3 As New Point3d(GlobalGPoint.X, GlobalGPoint.Y, GlobalGPoint.Z - Length)
            Dim end3 As New Point3d(GlobalGPoint.X, GlobalGPoint.Y, GlobalGPoint.Z + Length)

            'Draw the Text
            Dim textwidth As Integer = e.Display.Measure2dText("Global masses center", New Point2d(0, 0), False, 0, DisplayHeight, "Arial").Width
            Dim MyDot As New TextDot("Global masses center", New Point3d(GlobalGPoint.X + DisplayHeight + textwidth, GlobalGPoint.Y + (1.5 * DisplayHeight), GlobalGPoint.Z)) With {.FontFace = "Arial"}
            e.Display.DrawDot(MyDot, Rhino.ApplicationSettings.AppearanceSettings.ViewportBackgroundColor, MyColor, Rhino.ApplicationSettings.AppearanceSettings.ViewportBackgroundColor)

            'Draw the lines
            e.Display.DrawLine(start1, end1, MyColor, 2)
            e.Display.DrawLine(start2, end2, MyColor, 2)
            e.Display.DrawLine(start3, end3, MyColor, 2)
        End If

    End Sub

    Private Sub DrawMassPointDecoration(e As DrawEventArgs)

        Dim c As New Circle(New Point3d(50, 20, 0), 10)
        e.Display.DrawCircle(c, Color.Blue, 4)

    End Sub

    Protected Overrides Sub DrawOverlay(e As DrawEventArgs)
        MyBase.DrawOverlay(e)
        e.Display.DepthMode = DepthMode.AlwaysInFront

        Me.DrawAnnotations(e)
        Me.DrawGlobalGravityCenter(e)
        DrawMassPointDecoration(e)

    End Sub

    Protected Overrides Sub PostDrawObjects(e As DrawEventArgs)
        MyBase.PostDrawObjects(e)
        e.Display.DepthMode = DepthMode.AlwaysInFront

        Me.DrawAnnotations(e)

    End Sub

    Protected Overrides Sub DrawForeground(ByVal e As Rhino.Display.DrawEventArgs)
        MyBase.DrawForeground(e)
        e.Display.DepthMode = DepthMode.AlwaysInFront

        'Common variables
        Dim ViewPortBounds As Rectangle = e.Viewport.Bounds
        Dim pt As Point2d

        'Simplified version
        Dim text As String = "View related text"
        Dim DeckTitlewidth As Integer = e.Display.Measure2dText(text, New Point2d(0, 0), False, 0, 25, "Arial").Width
        pt = New Rhino.Geometry.Point2d(ViewPortBounds.Right - 25 - DeckTitlewidth, ViewPortBounds.Bottom - 100)
        e.Display.Draw2dText(text, System.Drawing.Color.Blue, pt, False, 25, "Arial")

        text = "subtext"
        Dim textwidth As Integer = e.Display.Measure2dText(text, New Point2d(0, 0), False, 0, 15, "Arial").Width
        pt = New Rhino.Geometry.Point2d(ViewPortBounds.Right - 30 - textwidth, ViewPortBounds.Bottom - 30)
        e.Display.Draw2dText(text, System.Drawing.Color.Red, pt, False, 15, "Arial")
    End Sub


    Protected Overrides Sub PreDrawObject(e As DrawObjectEventArgs)
        MyBase.PreDrawObject(e)
        'Store the information for later use in PostDrawObjects

    End Sub
End Class

